@@ -8,7 +8,9 @@ import subprocess
 def check_have_exuberant_ctags():
     """Check that the 'ctags' binary is *Exuberant* ctags (not etags etc)"""
     try:
-        return b"Exuberant" in subprocess.check_output(["ctags", "--version"], stderr=subprocess.PIPE)
+        return b"Exuberant" in subprocess.check_output(
+            ["ctags", "--version"], stderr=subprocess.PIPE
+        )
     except subprocess.CalledProcessError:
         return False
 
@@ -21,14 +23,20 @@ def create_tagsfile(git_repo_path, git_rev):
 
     :return: path to the generated tagsfile
     """
-    assert check_have_exuberant_ctags(), "'ctags' binary is missing or not *Exuberant* ctags"
+    assert (
+        check_have_exuberant_ctags()
+    ), "'ctags' binary is missing or not *Exuberant* ctags"
 
     _, target_tagsfile = tempfile.mkstemp()
     checkout_tmpdir = tempfile.mkdtemp()
     try:
-        subprocess.check_call(["git", "clone", "-q", "--shared", git_repo_path, checkout_tmpdir])
+        subprocess.check_call(
+            ["git", "clone", "-q", "--shared", git_repo_path, checkout_tmpdir]
+        )
         subprocess.check_call(["git", "checkout", "-q", git_rev], cwd=checkout_tmpdir)
-        subprocess.check_call(["ctags", "--fields=+l", "-Rno", target_tagsfile], cwd=checkout_tmpdir)
+        subprocess.check_call(
+            ["ctags", "--fields=+l", "-Rno", target_tagsfile], cwd=checkout_tmpdir
+        )
     finally:
         shutil.rmtree(checkout_tmpdir)
     return target_tagsfile
