@@ -8,7 +8,7 @@ import mimetypes
 import locale
 import warnings
 import subprocess
-import six
+
 try:
     import chardet
 except ImportError:
@@ -48,15 +48,17 @@ class ProxyFix(WerkzeugProxyFix):
     :param app: the WSGI application
     :param num_proxies: the number of proxy servers in front of the app.
     """
+
     def __call__(self, environ, start_response):
-        script_name = environ.get('HTTP_X_SCRIPT_NAME')
+        script_name = environ.get("HTTP_X_SCRIPT_NAME")
         if script_name is not None:
-            if script_name.endswith('/'):
-                  warnings.warn(
-                      "'X-Script-Name' header should not end in '/' (found: %r). "
-                      "Please fix your proxy's configuration." % script_name)
-                  script_name = script_name.rstrip('/')
-            environ['SCRIPT_NAME'] = script_name
+            if script_name.endswith("/"):
+                warnings.warn(
+                    "'X-Script-Name' header should not end in '/' (found: %r). "
+                    "Please fix your proxy's configuration." % script_name
+                )
+                script_name = script_name.rstrip("/")
+            environ["SCRIPT_NAME"] = script_name
         return super(ProxyFix, self).__call__(environ, start_response)
 
 
@@ -76,25 +78,26 @@ class SubUri(object):
 
     Snippet stolen from http://flask.pocoo.org/snippets/35/
     """
+
     def __init__(self, app):
         warnings.warn(
             "'klaus.utils.SubUri' is deprecated and will be removed. "
             "Please upgrade your code to use 'klaus.utils.ProxyFix' instead.",
-            DeprecationWarning
+            DeprecationWarning,
         )
         self.app = app
 
     def __call__(self, environ, start_response):
-        script_name = environ.get('HTTP_X_SCRIPT_NAME', '')
+        script_name = environ.get("HTTP_X_SCRIPT_NAME", "")
         if script_name:
-            environ['SCRIPT_NAME'] = script_name.rstrip('/')
+            environ["SCRIPT_NAME"] = script_name.rstrip("/")
 
-        if script_name and environ['PATH_INFO'].startswith(script_name):
+        if script_name and environ["PATH_INFO"].startswith(script_name):
             # strip `script_name` from PATH_INFO
-            environ['PATH_INFO'] = environ['PATH_INFO'][len(script_name):]
+            environ["PATH_INFO"] = environ["PATH_INFO"][len(script_name) :]
 
-        if 'HTTP_X_SCHEME' in environ:
-            environ['wsgi.url_scheme'] = environ['HTTP_X_SCHEME']
+        if "HTTP_X_SCHEME" in environ:
+            environ["wsgi.url_scheme"] = environ["HTTP_X_SCHEME"]
 
         return self.app(environ, start_response)
 
@@ -105,42 +108,48 @@ def timesince(when, now=time.time):
 
 
 def formattimestamp(timestamp):
-    return datetime.datetime.fromtimestamp(timestamp).strftime('%b %d, %Y %H:%M:%S')
+    return datetime.datetime.fromtimestamp(timestamp).strftime("%b %d, %Y %H:%M:%S")
 
 
 def guess_is_binary(dulwich_blob):
-    return any(b'\0' in chunk for chunk in dulwich_blob.chunked)
+    return any(b"\0" in chunk for chunk in dulwich_blob.chunked)
 
 
 def guess_is_image(filename):
     mime, _ = mimetypes.guess_type(filename)
     if mime is None:
         return False
-    return mime.startswith('image/')
+    return mime.startswith("image/")
 
 
 def encode_for_git(s):
     # XXX This assumes everything to be UTF-8 encoded
-    return s.encode('utf8')
+    return s.encode("utf8")
 
 
 def decode_from_git(b):
     # XXX This assumes everything to be UTF-8 encoded
-    return b.decode('utf8')
+    return b.decode("utf8")
 
 
 def force_unicode(s):
     """Do all kinds of magic to turn `s` into unicode"""
     # It's already unicode, don't do anything:
-    if isinstance(s, six.text_type):
+    try:
+        # Python < 3
+        text_type = unicode
+    except NameError:
+        text_type = str
+    if isinstance(s, text_type):
         return s
 
     last_exc = None
     # Try some default encodings:
     try:
-        return s.decode('utf-8')
+        return s.decode("utf-8")
     except UnicodeDecodeError as exc:
-        last_exc = exc
+        pass
+
     try:
         return s.decode(locale.getpreferredencoding())
     except UnicodeDecodeError:
@@ -148,11 +157,11 @@ def force_unicode(s):
 
     if chardet is not None:
         # Try chardet, if available
-        encoding = chardet.detect(s)['encoding']
+        encoding = chardet.detect(s)["encoding"]
         if encoding is not None:
             return s.decode(encoding)
 
-    raise last_exc  # Give up.
+    return s.decode('latin1', 'replace')
 
 
 def extract_author_name(email):
@@ -164,7 +173,7 @@ def extract_author_name(email):
     >>> extract_author_name("noname@example.com")
     "noname@example.com"
     """
-    match = re.match('^(.*?)<.*?>$', email)
+    match = re.match("^(.*?)<.*?>$", email)
     if match:
         return match.group(1).strip()
     return email
@@ -172,7 +181,7 @@ def extract_author_name(email):
 
 def is_hex_prefix(s):
     if len(s) % 2:
-        s += '0'
+        s += "0"
     try:
         binascii.unhexlify(s)
         return True
@@ -197,13 +206,13 @@ def subpaths(path):
     [('foo', 'foo'), ('bar', 'foo/bar'), ('spam', 'foo/bar/spam')]
     """
     seen = []
-    for part in path.split('/'):
+    for part in path.split("/"):
         seen.append(part)
-        yield part, '/'.join(seen)
+        yield part, "/".join(seen)
 
 
 def shorten_message(msg):
-    return msg.split('\n')[0]
+    return msg.split("\n")[0]
 
 
 def replace_dupes(ls, replacement):
@@ -230,37 +239,42 @@ def guess_git_revision():
     This is used to display the "powered by klaus $VERSION" footer on each page,
     $VERSION being either the SHA guessed by this function or the latest release number.
     """
-    git_dir = os.path.join(os.path.dirname(__file__), '..', '.git')
+    git_dir = os.path.join(os.path.dirname(__file__), "..", ".git")
     try:
-        return force_unicode(subprocess.check_output(
-            ['git', 'log', '--format=%h', '-n', '1'],
-            cwd=git_dir
-        ).strip())
+        return force_unicode(
+            subprocess.check_output(
+                ["git", "log", "--format=%h", "-n", "1"], cwd=git_dir
+            ).strip()
+        )
     except OSError:
         # Either the git executable couldn't be found in the OS's PATH
         # or no ".git" directory exists, i.e. this is no "bleeding-edge" installation.
         return None
 
 
-def sanitize_branch_name(name, chars='./', repl='-'):
+def sanitize_branch_name(name, chars="./", repl="-"):
     for char in chars:
         name = name.replace(char, repl)
     return name
 
 
 def escape_html(s):
-    return s.replace(b'&', b'&amp;').replace(b'<', b'&lt;') \
-            .replace(b'>', b'&gt;').replace(b'"', b'&quot;')
+    return (
+        s.replace(b"&", b"&amp;")
+        .replace(b"<", b"&lt;")
+        .replace(b">", b"&gt;")
+        .replace(b'"', b"&quot;")
+    )
 
 
 def tarball_basename(repo_name, rev):
     """Determine the name for a tarball."""
-    rev = sanitize_branch_name(rev, chars='/')
-    if rev.startswith(repo_name + '-'):
+    rev = sanitize_branch_name(rev, chars="/")
+    if rev.startswith(repo_name + "-"):
         # If the rev is a tag name that already starts with the repo name,
         # skip it.
         return rev
-    elif len(rev) >= 2 and rev[0] == 'v' and not rev[1].isalpha():
+    elif len(rev) >= 2 and rev[0] == "v" and not rev[1].isalpha():
         # If the rev is a tag name prefixed by a 'v', skip the 'v'.
         # So, v-1.0 -> 1.0, v1.0 -> 1.0, but vanilla -> vanilla.
         return "%s-%s" % (repo_name, rev[1:])
@@ -279,6 +293,6 @@ def repo_human_name(path):
     3. /x/y -> y
     """
     name = path.rstrip(os.sep).split(os.sep)[-1]
-    if name.endswith('.git'):
+    if name.endswith(".git"):
         name = name[:-4]
     return name
